package com.kdanmobile.reader.screen.view

import android.content.Context
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.AttributeSet
import android.view.LayoutInflater
import android.widget.RelativeLayout
import com.kdanmobile.reader.R
import com.kdanmobile.reader.ReaderViewModel
import com.kdanmobile.reader.screen.adapter.ThumbnailAdapter
import com.kdanmobile.reader.screen.handler.PdfInfoHandler
import com.kdanmobile.reader.screen.handler.ThumbnailHandler
import com.kdanmobile.reader.widget.drag.OnRecyclerItemClickListener
import kotlinx.android.synthetic.main.view_thumbnail.view.*

class ThumbnailView: RelativeLayout {
    companion object {
        private var currentPage = 0
    }
    private lateinit var adapter: ThumbnailAdapter

    constructor(context: Context, viewModel: ReaderViewModel) : super(context) {
        initView(viewModel, viewModel)
    }

    constructor(context: Context, attributeSet: AttributeSet, viewModel: ReaderViewModel) : super(context, attributeSet) {
        initView(viewModel, viewModel)
    }

    constructor(context: Context, attributeSet: AttributeSet, defStyleAttr: Int, viewModel: ReaderViewModel) : super(context, attributeSet, defStyleAttr) {
        initView(viewModel, viewModel)
    }

    private fun initView(pdfInfoHandler: PdfInfoHandler, thumbnailHandler: ThumbnailHandler) {
        LayoutInflater.from(context).inflate(R.layout.view_thumbnail, this)
        val layoutManager = LinearLayoutManager(context)
        layoutManager.orientation = LinearLayoutManager.VERTICAL

        id_km_thumb_recycler.setHasFixedSize(true)
        id_km_thumb_recycler.layoutManager = layoutManager
        id_km_thumb_recycler.layoutManager = LinearLayoutManager(context)
        id_km_thumb_recycler.addOnItemTouchListener(object : OnRecyclerItemClickListener(id_km_thumb_recycler) {
            override fun onItemClick(viewHolder: RecyclerView.ViewHolder) {
                onScrollToPosition(viewHolder.adapterPosition, true)
                pdfInfoHandler.setCurrentPage(viewHolder.adapterPosition)
            }

            override fun onItemLongClick(viewHolder: RecyclerView.ViewHolder) {

            }
        })

        adapter = ThumbnailAdapter(pdfInfoHandler, thumbnailHandler)
        id_km_thumb_recycler.adapter = adapter
        onScrollToPosition(currentPage, true)
    }

    private fun onScrollToPosition(position: Int, notify: Boolean) {
        currentPage = position

        if (null != adapter && notify) {
            adapter.setCurrentPage(position)
        }

        if (null != id_km_thumb_recycler) {
            id_km_thumb_recycler.scrollToPosition(position)
        }
    }
}